import { base, getToken } from './_config'

export async function getGtfsArchivo(params) {
    const query = !params ? '' : '?' + (new URLSearchParams(params).toString());
    const res = await fetch(`${base}/gtfs-archivo/${query}`, {
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.json()
    return res.json()
}

export async function getGtfsArchivoId(id) {
    const res = await fetch(`${base}/gtfs-archivo/${id}/`, {
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.json()
    return res.json()
}

export async function createGtfsArchivo(data) {
    const form = new FormData()
    for (let key in data) {
        if (key === 'archivo') {
            const file = data[key]
            form.append(key, file, file.name)
        } else {
            form.append(key, data[key])
        }
    }

    const res = await fetch(`${base}/gtfs-archivo/`, {
        method: 'POST',
        body: form,
        headers: { "Authorization": `Bearer ${getToken()}` }
    })
    if (!res.ok) throw await res.json()
    return res.json()
}

export async function updateGtfsArchivo({ id_red: id = null, ...data }) {
    const res = await fetch(`${base}/gtfs-archivo/${id}/`, {
        method: 'PATCH',
        body: JSON.stringify(data),
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.json()
    return res.json()
}

export async function deleteGtfsArchivo(id) {
    const res = await fetch(`${base}/gtfs-archivo/${id}/`, {
        method: 'DELETE',
        headers: { "Authorization": `Bearer ${getToken()}`, "Content-Type": "application/json" }
    })
    if (!res.ok) throw await res.json()
    return res.text()
}